@@ -103,12 +103,15 @@ module CorePrelude
     , (<>)
       -- ** Folds and traversals
     , Data.Foldable.Foldable
+    , Data.Foldable.asum
     , Data.Traversable.Traversable
       -- ** arrow
     , Control.Arrow.first
     , Control.Arrow.second
     , (Control.Arrow.***)
     , (Control.Arrow.&&&)
+      -- ** Bool
+    , bool
       -- ** Maybe
     , Data.Maybe.mapMaybe
     , Data.Maybe.catMaybes
@@ -228,6 +231,10 @@ import qualified Data.List
 import System.IO.Error hiding (catch, try)
 import qualified GHC.Exts
 
+#if MIN_VERSION_base(4,7,0)
+import Data.Bool (bool)
+#endif
+
 #if MIN_VERSION_base(4,5,0)
 import Data.Monoid ((<>))
 #endif
@@ -238,6 +245,11 @@ type UVector = Data.Vector.Unboxed.Vector
 type SVector = Data.Vector.Storable.Vector
 
 
+#if !MIN_VERSION_base(4,7,0)
+bool :: a -> a -> Bool -> a
+bool f t b = if b then t else f
+#endif
+
 #if !MIN_VERSION_base(4,5,0)
 
 infixr 6 <>
